@@ -76,10 +76,10 @@ class Camera:
     def _crt_time_str(self):
         """
         返回当前时间的字符串表示
-        示例：'2022-11-13_15:34:29'
+        示例：'2022-11-13_15-34-29'
         :return:
         """
-        return time.strftime("%Y-%m-%d_%H:%M:%S", time.localtime())
+        return time.strftime("%Y-%m-%d_%H-%M-%S", time.localtime())
 
     def _cft_fn(self):
         return f"{self._crt_time_str()}_{int(time.time() % 1 * 1000)}"
